# frozen_string_literal: true
module Hermes
  module Api
    module Dmo
      class DocumentationController <  ActionController::Base
        # This action uses query string parameters because it gets run
        # by an HTTP GET request, but this does not make any difference
        # to the way in which the parameters are accessed. The URL for
        # this action would look like this in order to list activated
        # clients: /clients?status=activated
        def show_doc
          return head :not_found if HERMES_CONFIG['environment'] == 'PROD'
          @md_doc ="" 
          Dir.glob(File.join(Rails.root,"packages","hermes", "app", "assets", "docs", "doc", "*")).sort.each do |file_name|
            @md_doc += File.read(file_name) + "\n\n"
          end

          @md_doc += "# Indexes \n\n"

          @md_doc += "Nom de l'index : clés de l'index \n\n"

          Rails::Mongoid.load_models(Hermes::Engine) unless Rails.env.production?

          Mongoid.models.sort { |a, b| a.name <=> b.name }.each do |model|
            begin 
              next unless model.name.include?("Hermes::")
              @md_doc += "## #{model.name.sub("Hermes::", "")} (#{model.collection.indexes.to_a.length}) \n\n"
              model.collection.indexes.sort { |a, b| a['name'] <=> b['name'] }.each do |index|
                @md_doc += "#{index['name']} : #{index['key']} \n\n"
              end 
            rescue => e

            end
          end 

          render template: "show_doc"
        end

        def show_changelog
          @md_doc = File.read(File.join(Rails.root,"packages","hermes", "changelog.md"))
          render template: "show_doc"
        end

        def show_old_changelog
          @md_doc = File.read(File.join(Rails.root,"packages","hermes", "old-changelog.md"))
          render template: "show_doc"
        end
      end
    end
  end
end
