# frozen_string_literal: true

module Hermes
  module Api
    module Dmo
      class HousingChannelSettingsController < Hermes::Api::Dmo::ApplicationController
        hermes_errors 'housing_channel_error'

        before_action :authorize_administrator!
        set_instance_for %i[index show create update destroy]

        rescue_from Hermes::Errors::HousingChannelError do |exception|
          render_json_error(:unprocessable_entity, :housing_channel_error, { message: exception.message })
        end

        class << self
          def mutate_params
            {
              department: {type: 'String'},
              insee_code: {type: 'String'},
              housing_channel_keys: {type: 'Array'},
            }
          end 
      
          def acceptable_params
            {

            }.merge(self.mutate_params).merge(super)
          end 
      
          def regex_params
            {
      
            }
          end 
        end

        def index
          acceptable_params *self.class.acceptable_params.keys
          super
        end

        def authorize_administrator!
          return render_json_error(:unauthorized, :not_admin) unless current_user_roles.include?('Administrator')
        end
      end
    end
  end
end