# frozen_string_literal: true
# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class UserFiltersController < Hermes::Api::Dmo::ApplicationController

        class << self
          def mutate_params
            {
              key: {type: 'String'},
              user_id: {type: 'String'},
              value: {type: 'Hash'},
            }
          end 
      
          def acceptable_params
            {
            }.merge(self.mutate_params).merge(super)
          end 
      
          def regex_params
            {

            }
          end 
        end

        before_filter :merge_json_params, only: [:update, :create]
        
        def index
          acceptable_params *self.class.acceptable_params.keys
          
          paginate(
            index_aggregation.where(user_id: current_user.id),
            each_serializer: @serializer,
            **@options
          )
        end
          
        def show 
          return render_json_error(:not_found, :instance_not_found) unless @instance
          return render_json_error(:unauthorized, :cannot_see_this_user_filter) unless is_user_filter

          super
        end
        
        def create
          return render_json_error(:unprocessable_entity, :missing_params) unless mutate_valid_params[:user_id].present? && mutate_valid_params[:key].present?
          return render_json_error(:unauthorized, :cannot_create_filter_for_other_user) unless current_user.id.to_s == mutate_valid_params[:user_id]

          if already_one_filter = Hermes::UserFilter.find_by(user_id: mutate_valid_params[:user_id], key: mutate_valid_params[:key])
            @instance = already_one_filter
            return respond_with_errors(@instance) unless @instance.update(mutate_valid_params)

            return render(jsonapi: @instance, serializer: @serializer, status: :created)
          end 

          super
        end

        def destroy 
          return render_json_error(:not_found, :instance_not_found) unless @instance
          return render_json_error(:unauthorized, :cannot_delete_other_user_filter) unless is_user_filter
          return render(json: @instance.errors, status: :unprocessable_entity) unless @instance.destroy

          render(body: nil, status: :no_content)
        end 

        private 

        def is_user_filter
          @instance&.user_id == current_user.id
        end 

        def set_instance
          @instance = @model.find_by(id: params[:id]) if params[:id]
        end

        # Fix fix pour les values avec un tableau vide non testé dans rpsec car on arrive pas à reproduire mais testé en local.
        def merge_json_params
          return if Rails.env.test?
          body = request.body.read
          request.body.rewind
          params.merge!(ActiveSupport::JSON.decode(body)) unless body == ""
        end
      end
    end
  end
end
