
class Hermes::HermesMailer < ::ActionMailer::Base
  self.delivery_method = :queued
  default :from => "#{APP_CONFIG["smtp_no_reply"]}" || 'no-reply@plugandwork.fr',
          :return_path => "#{APP_CONFIG["smtp_no_reply"]}" || 'no-reply@plugandwork.fr'
  layout 'hermes'

  def send_notification_email(notification_id)
    @notification      = ::NotificationCenter::Notification.find notification_id
    @notifiable        = @notification.notifiable
    @target            = @notification.targetable
    @mail_template     = MailTemplate.find_by(default: true) || MailTemplate.new

    notifiable_class   = @notification.notifiable.class.name.split('::').last
    contents           = "::NotificationsCenter::#{notifiable_class}".constantize.new(instance: @notification)

    @full_name         = contents.full_name.titleize
    @title             = contents.title
    @body              = contents.body
    @header_text       = contents.header_text
    @unsubscribe_link  = contents.unsubscribe_link

    @action_link       = contents.actions && "#{HERMES_CONFIG['frontend_url']}#{contents.actions[:link]}" 
    @action_title      = contents.actions && contents.actions[:title]

    from = @notification.sender&.email_with_name || "#{APP_CONFIG["smtp_no_reply"]}"
    to = HERMES_CONFIG['smtp_force_recipients'].blank? ? contents.email : HERMES_CONFIG['smtp_force_recipients']

    mail(from: from, to: to, subject: @title)
  end

  def send_email(to, subject, body)
    from = APP_CONFIG["smtp_no_reply"] || 'support@plugandwork.fr'
    to = HERMES_CONFIG['smtp_force_recipients'] unless HERMES_CONFIG['smtp_force_recipients'].blank?
    @mail_template  = MailTemplate.find_by(default: true) || MailTemplate.new
    @body = body

    mail(from: from, to: to, subject: subject)
  end 
end