
# frozen_string_literal: true

module Hermes
  class Eligible
    include Hermes::Concerns::CommonFieldsConcern

    field :is_department_eligible, type: Boolean
    field :is_seeked_eligible, type: Boolean
    field :is_bordering_eligible, type: Boolean
    field :is_seeked_bordering_eligible, type: Boolean
    field :offer_is_published, type: Boolean

    belongs_to(:housing_offer, class_name: 'Hermes::HousingOffer')
    belongs_to(:housing_request, class_name: 'Hermes::HousingRequest')
    belongs_to(:entity, class_name: 'Hermes::Entity', index: true)

    index({ housing_offer_id: 1, entity_id: 1 }, {background: true })
    index({ housing_offer_id: 1, is_department_eligible: 1, entity_id: 1 }, {background: true })
    index({ housing_offer_id: 1, is_seeked_bordering_eligible: 1, entity_id: 1 }, {background: true })

    writer_roles 'Superadmin', 'Administrator'
    reader_roles 'Manager'
  end
end