# frozen_string_literal: true

::NotificationCenter::Notification.class_eval do
  field :is_slow, type: Boolean, default: false # slow notification (like email) will be sent in a dedicated queue
 
  def send_notification
    if has_level?
      if subscription.subscribed_to_email?(key) && targetable.emailable? && channels.include?('email')
        mailer_action.deliver_now
      end

      if subscription.subscribed_to_slack?(key) && targetable.slackable? && channels.include?('slack')
        slack_prov = ::NotificationCenter::Slack.new(self)
        slack_prov.notify({})
      end

      if subscription.subscribed_to_sms?(key) && targetable.smsable? && channels.include?('sms')
        sms_prov = targetable.sms_provider.new(self)
        sms_prov.send_sms
      end

      if subscription.subscribed_to_web?(key) && targetable.webable? && channels.include?('web')
        if targetable.is_a?(User) && notifiable.is_a?(Message)
          if datas[:send_im_args].present?
            targetable.send_im(*datas[:send_im_args])
          elsif datas[:uids].present?
            User.where(:id.in => datas[:uids]).each do |u|
              Rails.logger.debug "IM SYS #{u.full_name}"
              u.im(*datas[:im_args])
            end
          end
        end
      end
    end
  end
end
