# frozen_string_literal: true

TZInfo::Timezone.class_eval do
  def period_for_local(local, dst = Timezone.default_dst)
    results = periods_for_local(local)
    
    if results.empty?
      raise PeriodNotFound
    elsif results.size < 2
      results.first
    else
      # ambiguous result try to resolve
      
      if !dst.nil?
        matches = results.find_all {|period| period.dst? == dst}
        results = matches if !matches.empty?            
      end
      
      if results.size < 2
        results.first
      else
        results
        # still ambiguous, try the block
        
        if block_given?
          results = yield results
        end

        if results.is_a?(TZInfo::TimezonePeriod)
          results
        # CUSTOM
        # Certaine zones ont des périodes qui se chevauchent spécifiquement pour les dates 08 Oct 1914 et 08 Oct 1944
        # On ne peut pas connaitre la bonne période sans plus d'infos du coup on prend la première
        elsif results && results.is_a?(Array) 
          results.first
        else          
          raise TZInfo::AmbiguousTime, "#{local} is an ambiguous local time."
        end
      end
    end      
  end
end
