# frozen_string_literal: true

module Hermes
  # HousingRequest serializer
  class RequiredDocumentSerializer < Hermes::ApplicationSerializer
    type 'required_documents'

    attributes :nature,
               :type,
               :category,
               :is_for_main_applicant,
               :dependent_first_name,
               :dependent_last_name,
               :disability_index,
               :applicant_id,
               :applicant_full_name
    

    def added_to_object_cache_key
      current_user&.id
    end

    def check_if_new_name(type)
      new_name_hash = {
        "Avis d'imposition N-1" => "Avis d'imposition 2021 sur les revenus de l'année 2020" ,
        "Avis d'imposition N-2" => "Avis d'imposition 2020 sur les revenus de l'année 2019" ,
      }
        new_name_hash[type] || type
    end
    
    def type
      splitted_type = object.type.split("####")
    
      if (splitted_type[1])
        check_if_new_name(splitted_type[1])
      else
        splitted_type2 = object.type.split("****")
        if (splitted_type2[1])
          check_if_new_name(splitted_type2[1])
        else
          check_if_new_name(object.type)
          end
      end
    end
    
    def dependent_infos
      splitted_type = object.type.split("####")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end

    def disability_index
      splitted_type = object.type.split("****")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end

    def dependent_first_name
      dependent_infos && dependent_infos["first_name"]
    end

    def dependent_last_name
      dependent_infos && dependent_infos["last_name"]
    end

    def applicant_full_name
      Hermes::Applicant.find(object.applicant_id)&.full_name
    end 

    def is_for_main_applicant
      main_applicant_id = @instance_options[:main_applicant_id]
      return unless main_applicant_id
      
      (object.applicant.id.to_s == main_applicant_id.to_s)
    end

  end
end