module Hermes
  module Statuses
    class HousingApplication < Base

      ACTIVE_STATUS = [
        'PLO',
        'EN ATTENTE',
        'TRANSMIS BAILLEUR',
        "A L'ETUDE ALS",
        'INSCRIPTION CAL',
        'RETENUE EN CAL',
        'RETENUE EN CAL SOUS CONDITIONS',
        'RETENUE EN CAL SOUS RESERVE',
      ]

      CANCEL_STATUS = [
        'ANNULEE',
        'ANNULEE BAILLEUR',
        'DESISTEMENT',
        "DESISTEMENT SALARIE",
        'DESISTEMENT SALARIE AVANT CAL',
        'DESISTEMENT SALARIE CAL',
        'DESISTEMENT APRES CAL',
        'DESISTEMENT APRES VISITE',
        'DESISTEMENT AVANT CAL',
        'ABANDON BAILLEUR',
      ]
      
      INACTIVE_STATUS = CANCEL_STATUS + [
        'REPRIS BAILLEUR',
        'NON RETENUE',
        'NON RETENUE EN CAL',
        'REFUSEE EN CAL',
        'LOGE',
      ]

      ACTIVE_VISIT_STATUS = [
        'VISITE PROPOSEE',
        'VISITE EFFECTUEE',
        'ACCORD APRES VISITE'
      ]

      INACTIVE_VISIT_STATUS = [
        'DESISTEMENT APRES VISITE',
      ]

      STATUS_ORDER = {
        "TRANSMIS BAILLEUR" => 0,
        "INSCRIPTION CAL" => 1,
        "VISITE PROPOSEE" => 2,
        "VISITE EFFECTUEE" => 3,
        "RETENUE EN CAL SOUS RESERVE" => 4,
        "RETENUE EN CAL SOUS CONDITIONS" => 5,
        "RETENUE EN CAL" => 6,
        "REFUSEE EN CAL" => 7,
        "DESISTEMENT" => 7,
        "LOGE" => 7,
      }

      def self.possible_status
        {
          status: ACTIVE_STATUS + INACTIVE_STATUS,
          visit_status: ACTIVE_VISIT_STATUS + INACTIVE_VISIT_STATUS
        }
      end

      def self.all_possible_status
        ACTIVE_STATUS + INACTIVE_STATUS + ACTIVE_VISIT_STATUS + INACTIVE_VISIT_STATUS
      end

      def self.active_status
        ACTIVE_STATUS
      end 

      def self.inactive_status
        INACTIVE_STATUS
      end 

      def self.cancel_status
        CANCEL_STATUS
      end 

      def self.active_visit_status
        ACTIVE_VISIT_STATUS
      end 

      def self.inactive_visit_status
        INACTIVE_VISIT_STATUS
      end 

      def self.order_status
        STATUS_ORDER
      end 
      
      def self.sopra_code(status)
        case I18n.transliterate(status).upcase
        when 'INSCRIPTION CAL'
          "INSCAL"
        when 'RETENUE EN CAL SOUS RESERVE'
          "DESCAL"
        when 'RETENUE EN CAL'
          "DESCAL01"
        when 'RETENUE EN CAL SOUS CONDITIONS'
          "DESCAL02"
        when 'REFUSEE EN CAL'
          "DESCAL03"
        when 'DESISTEMENT'
          "REFLOG"
        when 'VISITE PROPOSEE'
          "VISPRO"
        when 'VISITE EFFECTUEE'
          "VISEFF"
        when 'LOGE'
          "RADATT"
        when 'ABANDON BAILLEUR'
          "ABAN"
        end
      end
    end
  end
end