require 'rails_helper'

module Hermes
	RSpec.describe ::Api::AuthController, type: :controller do
    include Devise::Test::ControllerHelpers
    routes { Rails.application.routes }

    let!(:password) { 'password' }
    let!(:user) { create(:user, password: password, password_confirmation: password) }

    it 'use the same error message for failure in login' do
      expect(I18n.t('devise.failure.invalid')).to eq('Courriel ou mot de passe incorrect.')
      expect(I18n.t('devise.failure.user.not_found_in_database')).to eq('Courriel ou mot de passe incorrect.')
    end

    it 'can login' do 
      post 'token', { username: user.email, password: password }
      expect(response).to have_http_status(200)
    end

    it 'wrong password' do 
      post 'token', { username: user.email, password: 'wrong_password' }
      json = JSON.parse(response.body)
      expect(response).to have_http_status(401)
      expect(json['info']).to include("Problème d'identifiant ou de mot de passe ou de niveau de compte pour")
    end

    it 'wrong username' do 
      post 'token', { username: 'wrong_login', password: password }
      json = JSON.parse(response.body)
      expect(response).to have_http_status(401)
      expect(json['info']).to include("Problème d'identifiant ou de mot de passe ou de niveau de compte pour")
    end
	end 
end 
