require 'rails_helper'

RSpec.describe Hermes::BoClient::Mappings::HousingOfferMap, type: :helper do
  describe 'minimal_number_format' do 
    let!(:offer) { create(:housing_offer)}

    subject { Hermes::BoClient::Mappings::HousingOfferMap.new({ housing_offer_id: offer.id}) }

    it 'for nil' do 
      expect(subject.latitude).to eq(nil)
      expect(subject.longitude).to eq(nil)
    end 

    it 'for 0' do
      offer.update(latitude: 0, longitude: 0)
      expect(subject.latitude).to eq('0')
      expect(subject.longitude).to eq('0')
    end

    it 'for 0.0' do
      offer.update(latitude: 0.0, longitude: 0.0)
      expect(subject.latitude).to eq('0')
      expect(subject.longitude).to eq('0')
    end

    it 'for 0.0000000000' do
      offer.update(latitude: 0.0000000000, longitude: 0.0000000000)
      expect(subject.latitude).to eq('0')
      expect(subject.longitude).to eq('0')
    end

    it 'for 0.0000000001' do
      offer.update(latitude: 0.0000000001, longitude: 0.0000000001)
      expect(subject.latitude).to eq('0.0000000001')
      expect(subject.longitude).to eq('0.0000000001')
    end

    it 'for normal number' do 
      offer.update(latitude: 45.1234567890, longitude: 45.1234567890)
      expect(subject.latitude).to eq('45.123456789')
      expect(subject.longitude).to eq('45.123456789')
    end 
  end
end