require 'rails_helper'
require 'vcr_config'

dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'indiquerReference.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::AddRequestTask, type: :helper do
  let!(:xsd) { Nokogiri::XML::Schema(File.read(schema_path)) }
  let!(:user1) { create(:user) }
  let!(:applicant1) {
    create(
        :applicant,
        user: user1,
        monthly_charges: {},
        work_contract_type: "APP",
        has_other_employers: true,
        nationality: "1",
        family_situation:'V',
        year_minus_one: Date.current.year,
        amount_year_minus_one: "123",
        birth_date:Date.current,
        civility:"1",
        workplace_insee_code: "",
        sne_profile_creation_date: Date.current - 20.days,
        foreign_workplace_postal_code: "754114",
        foreign_workplace_locality: "Villedechine",
        foreign_workplace_country: "Chine",
        )
  }

  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end

  context 'with simple housing_request' do
    let!(:applicant) {create(:applicant)}
    let!(:housing_request1) do
      create(
          :housing_request,
          als_id: "0000001",
          is_active: true,
          main_applicant: applicant1,
          id_counter: "alpha",

          internal_ref: "alpha",
          seeked_localisation_list: [
              {
                  "nom": "Fréjus",
                  "code": "83061",
                  "codeDepartement": "83",
                  "codeRegion": "93",
                  "codesPostaux": [
                      "83600",
                      "83370"
                  ],
                  "population": 53168,
                  "_score": 1
              },
              {
                  "nom": "Fréjzus",
                  "code": "84061",
                  "codeDepartement": "81",
                  "codeRegion": "92",
                  "codesPostaux": [
                      "80600",
                      "80370"
                  ],
                  "population": 53168,
                  "_score": 1
              },
          ],
          forcing_duplicate: true,
          electronical_renewal: true,
          seeked_housing_categories: ["J"],
          seeking_first_floor: true,
          seeking_elevator: true,
          seeked_max_rent: 451,

          widen_request: true,
          seeked_types: ["T1", "T2"],
          typology_range: ["T1"],
          housing_type_list:["HLM"],
          actual_housing_details: {
            "postal_code"=>"75004",
            "appartment"=>"12",
            "floor"=>"12",
            "stair"=>"12",
            "building"=>"12",
            "company_adress"=>"douzeee",
            "number"=>"12",
            "way"=>"douzeee",
            "known_place"=>"douzeee",
            "district"=>"Paris",
            "address_insee_code"=>"75104"}, 
                      postal_details: {"appartment_building"=>"12",
            "appartment_staircase"=>"12",
            "appartment_floor"=>"12",
            "appartment_number"=>"12",
            "address_number"=>"12",
            "address_street"=>"douze",
            "address_add_address"=>"douze",
            "address_place"=>"douze",
            "postal_code"=>"75002",
            "district"=>"Paris",
            "address_insee_code"=>"75102"},
                      owned_housing_details: {"type"=>nil,
            "postal_code"=>nil,
            "district"=>nil
          },
          requester_lastname: "alpha",
          requester_firstname: "alpha",
          is_house_owner: true,
          motivations: ["02","01"],
      )
    end
    let!(:nud3) do
      create(
          :nud,
          housing_request: housing_request1,
          department: '14',
          creation_date: '2017-23-14T14:53:22',
          unique_number:"123456789012345678"
      )
    end

    let!(:housing_request_initializer1) do
      create(
        :housing_request_initializer,
        housing_request: housing_request1
       
      )
    end
   
    describe 'using to_xml' do
      let!(:add_request_task1) do
        build(
            :add_request_task,
            options: {nud_id: housing_request1.nud_ids[0] ,housing_request_id: housing_request1.reload.id }
        )
      end
      it 'should return a valid xml' do
        xsd.validate(Nokogiri::XML(add_request_task1.to_xml))
        add_request_task1.validate_xml
        housing_request1.reload
        so=Hermes::BoClient::AddRequestTask.new({:'housing_request_id'=> housing_request1.id})

        expect(housing_request1.reload.last_xml_validation_report).to eq("[]")
        so.execute
        VCR.use_cassette("flux30", :match_requests_on => [:method, :uri, :path]) do
          drain_all_jobs
        end

        expect(housing_request1.reload.last_send_has_error).to eq(true)
        
        expect(xsd.validate(Nokogiri::XML(add_request_task1.to_xml)).length).to eq(0)
      end
    end
  end
end