require 'rails_helper'
require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')

RSpec.describe BatchTasks::RequestWaitingForValidation, type: :service do
  subject { described_class.new }

  describe 'generate_and_enqueue_notification' do 
    let!(:user1) {create(:user, auth_roles: ['entreprise'])}
    let!(:user2) {create(:user, auth_roles: ['entreprise'])}
    let!(:user3) {create(:user, auth_roles: ['demandeur'])}

    let!(:entity1) {create(:entity)}
    let!(:entity2) {create(:entity)}
    let!(:entity3) {create(:entity)}

    let!(:ur1) {create(:user_right, user: user1, type: 'entity', right: 'administrator', entity: entity1)}
    let!(:ur2) {create(:user_right, user: user1, type: 'entity', right: 'user', entity: entity2)}
    let!(:ur3) {create(:user_right, user: user1, type: 'entity', right: 'reader', entity: entity3)}

    let!(:hr1) {create(:complete_request)}
    let!(:hr2) {create(:complete_request)}
    let!(:hr3) {create(:complete_request)}

    before do 
      create_mail_template_default()
      hr1.set(entity_status: "A VALIDER", entity_id: entity1.id)
      hr2.set(entity_status: "A VALIDER", entity_id: entity2.id)
      hr3.set(entity_status: "A VALIDER", entity_id: entity3.id)
    end

    it 'works' do 
      expect do
        subject.generate_and_enqueue_notification
      end.to change { enqueued_jobs.select{|job| job[:job] == SlowNotifierJob }.length }.by 1

      async_notif_job = execute_last_job(SlowNotifierJob)
      last_Doc = Doc.last
      expect(last_Doc.file.data).to include("#{user1.email};2")
      expect(last_Doc.file.data).not_to include(user2.email)
      expect(last_Doc.file.data).not_to include(user3.email)
    end 
  end
end