module ActionController
  class TestCase
    module Behavior

      def process_with_custom_behavior(action, method, **args)
        munged_args = deep_munge(args.deep_dup)
        process_without_custom_behavior(action, method, **munged_args)
      end

      def deep_munge(value)
        case value
        when Array
          processed = value.map { |element| deep_munge(element) }.compact
          processed.empty? ? nil : processed
        when Hash
          value.symbolize_keys!
          value.each_with_object({}) do |(k, v), memo|
            processed = deep_munge(v)
            if processed.nil? && (v.is_a?(Array) || v.nil?)
              memo[k] = nil
            elsif !processed.nil?
              memo[k] = processed
            end
            memo[k] = false if v == false
          end
        else
          value
        end
      end

      alias_method :process_without_custom_behavior, :process
      alias_method :process, :process_with_custom_behavior
    end
  end
end